/*
 * This file is part of SDL_3dfx - Implementation of the 3dfx Glide API on top of SDL/OpenGL
 *
 * Glide test wrapper
 *
 *  SDL_3dfx is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  SDL_3dfx is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>
 */

#include "sdk2_glide.h"

#include <string.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>

extern const char *runTest(void);
extern const char *testDescription;

#define WIDTH 640
#define HEIGHT 480

int main(int argc, char *argv[])
{
	GrHwConfiguration hwc;
	const char *msg;

	if (argc < 2) {
		if ((msg = strrchr(argv[0], '/'))) msg++;
		else if ((msg = strrchr(argv[0], '\\'))) msg++;
		else msg = argv[0];
		printf("Test \"%s\": %s\nPress any key to begin...\n", msg, testDescription);
		getch();
	}

	if (!grSstQueryBoards(&hwc) || !hwc.num_sst) {
		fprintf(stderr, "3dfx Glide hardware not found!\n");
		exit(1);
	}
	grGlideInit();
	grSstSelect(0);
	if (!grSstWinOpen(0, GR_RESOLUTION_640x480, GR_REFRESH_60Hz, GR_COLORFORMAT_ARGB, GR_ORIGIN_UPPER_LEFT, 2, 0)) {
		fprintf(stderr, "Could not set video mode!\n");
		exit(1);
	}

	if ((msg = runTest())) {
		fprintf(stderr, "Test failed: %s!\n", msg);
		exit(1);
	}

	getch();

	fprintf(stderr, "Test successful.\n");
	grGlideShutdown();
	return 0;
}

